==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridGroupingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescriptionMetadata } from "./WebGridSortingStrategyDescriptionMetadata";
import { WebGridGroupingStrategyDescription } from "./WebGridGroupingStrategyDescription";
/**
 * @hidden
 */
var WebGridGroupingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridGroupingStrategyDescriptionMetadata, _super);
    function WebGridGroupingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridGroupingStrategyDescriptionMetadata.b = function (a) {
        if (WebGridGroupingStrategyDescriptionMetadata.a == null) {
            WebGridGroupingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridGroupingStrategyDescriptionMetadata.c(WebGridGroupingStrategyDescriptionMetadata.a);
        }
        if (a.j(WebGridGroupingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridGroupingStrategyDescriptionMetadata.a);
    };
    WebGridGroupingStrategyDescriptionMetadata.c = function (a) {
        WebGridSortingStrategyDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridGroupingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebGridGroupingStrategyDescriptionMetadata.d = function (a) {
        WebGridGroupingStrategyDescriptionMetadata.b(a);
        a.aa("WebGridGroupingStrategy", function () { return new WebGridGroupingStrategyDescription(); });
        a.z("WebGridGroupingStrategy", WebGridGroupingStrategyDescriptionMetadata.a);
    };
    WebGridGroupingStrategyDescriptionMetadata.$t = markType(WebGridGroupingStrategyDescriptionMetadata, 'WebGridGroupingStrategyDescriptionMetadata');
    WebGridGroupingStrategyDescriptionMetadata.a = null;
    return WebGridGroupingStrategyDescriptionMetadata;
}(Base));
export { WebGridGroupingStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridGroupingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescriptionMetadata } from "./WebGridSortingStrategyDescriptionMetadata";
import { WebGridGroupingStrategyDescription } from "./WebGridGroupingStrategyDescription";
/**
 * @hidden
 */
var WebGridGroupingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridGroupingStrategyDescriptionMetadata, _super);
    function WebGridGroupingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridGroupingStrategyDescriptionMetadata.b = function (a) {
        if (WebGridGroupingStrategyDescriptionMetadata.a == null) {
            WebGridGroupingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridGroupingStrategyDescriptionMetadata.c(WebGridGroupingStrategyDescriptionMetadata.a);
        }
        if (a.k(WebGridGroupingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridGroupingStrategyDescriptionMetadata.a);
    };
    WebGridGroupingStrategyDescriptionMetadata.c = function (a) {
        WebGridSortingStrategyDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridGroupingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGridGroupingStrategyDescriptionMetadata.d = function (a) {
        WebGridGroupingStrategyDescriptionMetadata.b(a);
        a.ac("WebGridGroupingStrategy", function () { return new WebGridGroupingStrategyDescription(); });
        a.ab("WebGridGroupingStrategy", WebGridGroupingStrategyDescriptionMetadata.a);
    };
    WebGridGroupingStrategyDescriptionMetadata.$t = markType(WebGridGroupingStrategyDescriptionMetadata, 'WebGridGroupingStrategyDescriptionMetadata');
    WebGridGroupingStrategyDescriptionMetadata.a = null;
    return WebGridGroupingStrategyDescriptionMetadata;
}(Base));
export { WebGridGroupingStrategyDescriptionMetadata };
